==> jammo-bin_0.7.15.tar.gz: jammo-bin-0.7.15/src/chum/3-6gui/quitconfirmation.c <==
#include <tangle.h>
#include <clutter/clutter.h>
#include <stdlib.h> //For exit()

#include "../jammo.h"  //jammo_get_actor_by_id
#include "../jammo-mentor.h"
#include "../../cem/cem.h"
#include "singinggame.h"

static void end_jammo(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer sequencer){
	cem_add_to_log("Quitted by player", J_LOG_INFO);
	singinggame_clean_songlist();
	clutter_main_quit();
}

void quitconfirmation_quit_confirmed(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
	cem_add_to_log("Quit confirmed", J_LOG_USER_ACTION);
	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "quit_byebye.spx", end_jammo, NULL);
}

void quitconfirmation_mentor_action(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
	//Hide mentor (withoud hiding)
	clutter_actor_set_width(CLUTTER_ACTOR(jammo_mentor_get_default()),0.1);
	clutter_actor_set_height(CLUTTER_ACTOR(jammo_mentor_get_default()),0.1);

	jammo_mentor_speak(jammo_mentor_get_default(), "quit_confirmation.spx");
	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "quit_confirmation.spx");
}

void quitconfirmation_cancel_action (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
	cem_add_to_log("Quit canceled", J_LOG_USER_ACTION);
	clutter_actor_set_width(CLUTTER_ACTOR(jammo_mentor_get_default()),309);
	clutter_actor_set_height(CLUTTER_ACTOR(jammo_mentor_get_default()),480);

	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "main_menu_idle.spx");
	tangle_action_execute(TANGLE_ACTION(jammo_get_object_by_id("quitconfirmation-cancel-action2")));
}

==> jammo-bin_1.0.0.tar.gz: jammo-bin-1.0.0/src/chum/3-6gui/quitconfirmation.c <==
#include <tangle.h>
#include <clutter/clutter.h>
#include <stdlib.h> //For exit()

#include "../jammo.h"  //jammo_get_actor_by_id
#include "../jammo-mentor.h"
#include "../../cem/cem.h"
#include "singinggame.h"
#include "main_menu.h"

static void end_jammo(JammoMentor* mentor, const gchar* speech, gboolean interrupted, gpointer sequencer){
	cem_add_to_log("Quitted by player", J_LOG_INFO);
	singinggame_clean_songlist();
	clutter_main_quit();
}

gboolean quitconfirmation_quit_confirmed(TangleActor* actor, gpointer data){
	cem_add_to_log("Quit confirmed", J_LOG_USER_ACTION);
	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "quit_byebye.spx", end_jammo, NULL);
	return TRUE;
}

//@show-completed
void quitconfirmation_mentor_action(TangleActor* actor, gpointer data){
	//Hide mentor (withoud hiding)
	clutter_actor_set_width(CLUTTER_ACTOR(jammo_mentor_get_default()),0.1);
	clutter_actor_set_height(CLUTTER_ACTOR(jammo_mentor_get_default()),0.1);

	jammo_mentor_speak(jammo_mentor_get_default(), "quit_confirmation.spx");
	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "quit_confirmation.spx");
}

gboolean quitconfirmation_cancel_action(TangleActor* actor, gpointer data){
	cem_add_to_log("Quit canceled", J_LOG_USER_ACTION);
	jammo_mentor_shut_up(jammo_mentor_get_default());
	clutter_actor_set_width(CLUTTER_ACTOR(jammo_mentor_get_default()),309);
	clutter_actor_set_height(CLUTTER_ACTOR(jammo_mentor_get_default()),480);

	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "main_menu_idle.spx");
	main_menu_go_back_to_main_menu(NULL,NULL);

	return TRUE;
}
